#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef long double ld;

#define sz(x) ((int) (x).size())
#define pb push_back
#define mp make_pair
#define fi first
#define se second

#define NAME "f"

const int maxn = 550;
const ld inf = 1.4e9;
const ld eps = 1e-12;

struct pt
{
	ld x, y;
	
	pt(ld nx = 0, ld ny = 0): x(nx), y(ny) {}
	
	pt operator - (const pt &p) const
	{
		return pt(x - p.x, y - p.y);
	}
	
	pt operator + (const pt &p) const
	{
		return pt(x + p.x, y + p.y);
	}
	
	pt operator * (ld k) const
	{
		return pt(x * k, y * k);
	}
	
	ld operator * (const pt &p) const
	{
		return x * p.x + y * p.y;
	}
};

struct halfplane
{
	ld A, B, C; // Ax + By + C > 0
	
	halfplane() {}
	halfplane(ld nA, ld nB, ld nC): A(nA), B(nB), C(nC) {}
	
	int sign(const pt &p) const
	{
		ld f = A * p.x + B * p.y + C;
		if (fabsl(f) < eps) return 0;
		return f < 0 ? -1 : 1;
	}
};

int n;
halfplane planes[maxn];
int m, ans[maxn], id[maxn];
pt pts1[maxn], pts[maxn];
ll v[maxn];

pt intersect(const halfplane &p, const pt &a, const pt &b)
{
	ld A = b.y - a.y, B = a.x - b.x, C = -A * a.x - B * a.y;
	ld det = A * p.B - B * p.A;
	ld dx = -C * p.B + B * p.C;
	ld dy = -A * p.C + C * p.A;
	return pt(dx / det, dy / det); 
}

bool finite()
{
	vector<pt> poly;
	poly.pb(pt(-inf, -inf));
	poly.pb(pt(inf, -inf));
	poly.pb(pt(inf, inf));
	poly.pb(pt(-inf, inf));
	for (int it = 0; it + 1 < n; ++it)
	{
		halfplane p = planes[it];
//		cerr << p.A << " " << p.B << " " << p.C << endl;
		vector<pt> npoly;
		for (size_t i = 0; i < poly.size(); ++i)
		{
			pt a = poly[i], b = poly[(i + 1) % poly.size()];
			npoly.pb(a);
//			cerr << p.sign(a) << " ";
			if (p.sign(a) * p.sign(b) < 0)
//				cerr << "LAL\n",
				npoly.pb(intersect(p, a, b));
		}
//		cerr << endl;
		poly.clear();
		bool fin = true;
		for (size_t i = 0; i < npoly.size(); ++i)
			if (p.sign(npoly[i]) >= 0)
			{
				poly.pb(npoly[i]);
//				cerr << npoly[i].x << " " << npoly[i].y << endl;
				pt a = poly.back();
				if (fabsl(fabsl(a.x) - inf) < eps || fabsl(fabsl(a.y) - inf) < eps)
					fin = false;
			}
//		if (fin) cerr << "FINITE" << endl;
		if (fin) return true;
	}
	return false;
}

bool solve()
{
	cin >> m;
	if (m == 0) return false;
	int mx = 0;
	for (int i = 0; i < m; ++i)
	{
		cin >> pts1[i].x >> pts1[i].y >> v[i];
		pts1[i].x *= 2;
		pts1[i].y *= 2;
		if (v[i] > v[mx])
			mx = i;
	}
	n = 0;
	for (int i = 0; i < m; ++i)
	{
		if (v[i] == v[mx])
			pts[n] = pts1[i], id[n] = i, n++;
		else
			ans[i] = 0;
	}
	
	for (int i = 0; i < n; ++i)
	{
		int cnt = 0;
		for (int j = 0; j < n; ++j)
		{
			if (i == j) continue;
			pt n = pts[i] - pts[j];
			pt p = (pts[j] + pts[i]) * 0.5;
			planes[cnt++] = halfplane(n.x, n.y, -(p * n));
		}
		if (finite()) ans[id[i]] = 0;
		else ans[id[i]] = 1;
	}
	for (int i = 0; i < m; ++i)
		printf("%d", ans[i]);
	printf("\n");
	return true;
}

int main()
{
	#ifdef LOCAL
	assert(freopen(NAME ".in", "r", stdin));
	#endif // LOCAL
	while (solve());
	#ifdef LOCAL
	cerr << "Time: " << double(clock()) / CLOCKS_PER_SEC << "\n";
	#endif // LOCAL
	return 0;
}
