#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>

#include <iostream>
#include <iomanip>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <deque>
#include <queue>
#include <stack>
#include <algorithm>


#define forn(i, n) for(int i = 0; i < int(n); i++)
#define mp make_pair
#define pb push_back
#define foreach(it, v) for(__typeof(v.begin()) it = v.begin(); it != v.end(); ++it)

using namespace std;

typedef long long ll;

const int MAXN = 100000 + 10;
const int MAXVAL = 2048;
const int MAXP = 11;
const ll MODULO = 998244353;

int n;

ll factorials[MAXN], revs[MAXN];
int sums[MAXN];
int howMuch[MAXP + 1];
int d[(1 << MAXP) + 1], nd[(1 << MAXP) + 1];

ll mult(ll a, ll b) {
	return (a * b) % MODULO;
}

void add(int & a, int b) {
	a += b;
	if(a >= MODULO)
		a -= MODULO;
}

void sub(int & a, int b) {
	a -= b;
	if(a < 0)
		a += MODULO;
}

ll getPow(ll a, ll p) {
	ll result = 1;
	while(p != 0) {
		if((p & 1) != 0)
			result = mult(result, a);
		a = mult(a, a);
		p >>= 1;
	}
	return result;
}

void precalc() {
	factorials[0] = factorials[1] = 1;
	for(int i = 2; i < MAXN; i++) {
		factorials[i] = mult(factorials[i - 1], i);
	}
	for(int i = 0; i < MAXN; i++) {
		revs[i] = getPow(factorials[i], MODULO - 2);
		assert(mult(factorials[i], revs[i]) == 1);
	}
}

ll C(ll k, ll n) {
	if(k > n)
		return 0;
	return mult(factorials[n], mult(revs[k], revs[n - k]));
}

int getLog(int p) {
	int result = 0;
	while(p != 1) {
		if((p & 1) != 0)
			return -1;
		++result;
		p >>= 1;
	}
	return result;
}

inline int go(int step) {
	return (step == 0) ? 1 : (2 * step);
}

void buildSums(int n) {
	memset(sums, 0, sizeof(sums));
	sums[0] = 1;
	for(int i = 1; i < MAXN; i++) {
		sums[i] = sums[i - 1];
		add(sums[i], C(i, n));
	}
}

int getSum(int l, int r) {
	int result = sums[r];
	if(l > 0)
		sub(result, sums[l - 1]);
	return result;
}

int getCurrentBit(int p, int n) {
	if(n == 0)
		return -1;
	int result = p;
	while((1 << p) < 2048 && n > 1) {
		++result;
		n >>= 1;
	}
	return result;
}

bool checkBit(int mask, int bit) {
	return (mask >> bit) & 1;
}

void setBit(int & mask, int bit) {
	mask |= (1 << bit);
}

int addBit(int maskBefore, int bit) {
	if(bit == -1)
		return maskBefore;
	for(; ; bit++) {
		if(!checkBit(maskBefore, bit)) {
			setBit(maskBefore, bit);
			break;
		}
	}
	return (maskBefore >= 2048 ? 2048 : maskBefore);
}

int solveOther() {
	memset(d, 0, sizeof(d));
	d[0] = 1;
	int total = (1 << MAXP) + 1;
	for(int i = 0; i <= MAXP; i++) {
		memset(nd, 0, sizeof(nd));
		buildSums(howMuch[i]);
		for(int take = 0; take <= howMuch[i];) {
			int nextTake = go(take);
			int currentWays = getSum(take, nextTake - 1);
			int currentBit = getCurrentBit(i, take);
			
			
			//printf("%d %d %d %d\n", i, take, currentWays, currentBit);

			for(int maskBefore = 0; maskBefore < total; maskBefore++) {
				//printf("Ways: %d %d\n", maskBefore, d[maskBefore]);
				int newMask = addBit(maskBefore, currentBit);
				//if(maskBefore <= 0)
				//printf("Merge: %d %d\n", maskBefore, newMask);
				add(nd[newMask], mult(d[maskBefore], currentWays));
			}
			
			take = nextTake;
		}
		
		memcpy(d, nd, sizeof(d));
	}
	
	return d[2048];
}

bool solve() {
	memset(howMuch, 0, sizeof(howMuch));
	scanf("%d", &n);
	if(n == 0)
		return false;
	int zeroes = 0;
	for(int i = 0; i < n; i++) {
		int value;
		scanf("%d", &value);
		if(value == 0) {
			++zeroes;
		} else {
			int l = getLog(value);
			if(l != -1)
				++howMuch[l];
		}
	}
	int result = mult(getPow(2, zeroes), solveOther());
	printf("%d\n", result);
	return true;
}

int main() {
	precalc();
	while(solve())
		;
	return 0;
}