#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>

#include <iostream>
#include <iomanip>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <deque>
#include <queue>
#include <stack>
#include <algorithm>


#define forn(i, n) for(int i = 0; i < int(n); i++)
#define mp make_pair
#define pb push_back
#define foreach(it, v) for(__typeof(v.begin()) it = v.begin(); it != v.end(); ++it)

using namespace std;

typedef long long ll;
typedef long double ld;

const int MAXN = 500;
const ld eps = 1e-7;

int n, m;

typedef pair < int, int > point_t;

ld Abs(ld a) {
	return (a < 0) ? -a : a;
}

struct Line {
	ld a, b, c;
	
	ld eval(point_t p) const {
		return a * p.first + b * p.second + c;
	}
	
	ld eval(ld x, ld y) const {
		return a * x + b * y + c;
	}
};


point_t points[MAXN];
int speeds[MAXN];
Line badLines[MAXN];

Line buildLine(point_t x, point_t y) {
	Line firstLine;
	{
		firstLine.a = y.second - x.second;
		firstLine.b = x.first - y.first;
		firstLine.c = y.first * x.second - x.first * y.second;
		assert(Abs(firstLine.eval(x)) < eps && Abs(firstLine.eval(y)) < eps);
	}
	Line secondLine;
	{
		ld xMiddle = x.first + (y.first - x.first) * 0.5;
		ld yMiddle = x.second + (y.second - x.second) * 0.5;
		
		secondLine.a = -firstLine.b;
		secondLine.b = firstLine.a;
		secondLine.c = firstLine.b * xMiddle - firstLine.a * yMiddle;
		assert(Abs(secondLine.eval(xMiddle, yMiddle)) < eps);
	}
	if(secondLine.eval(x) > 0) {
		firstLine.a = -firstLine.a;
		firstLine.b = -firstLine.b;
		firstLine.c = -firstLine.c;
	}
	assert(secondLine.eval(x) < eps);
	//printf("%lf\n", secondLine.eval(x));
	return secondLine;
}

inline ld getRand(bool positive) {
	ld x = rand();
	assert(x >= 0);
	if(!positive) x = -x;
	return x;
}

bool check(int badIndex, int targetSpeed) {
	//printf("CHECK %d\n", badIndex);
	point_t firstPoint = points[badIndex];
	m = 0;
	for(int i = 0; i < n; i++) {
		if(i != badIndex && speeds[i] == targetSpeed) {
			point_t secondPoint = points[i];
			if(firstPoint == secondPoint)
				return false;
			badLines[m++] = buildLine(firstPoint, secondPoint);
		}
	}
	bool ok = (m == 0);
	if(m > 0) {
		const ld BUBEN = 5;
		
		for(int i = 0; i < m && !ok; i++) {
			// Generate x
			if(Abs(badLines[i].b) > eps) {
				for(int it = 0; it <= 1; it++) {
					ld x = getRand(it == 0);
					ld y = (-badLines[i].c - badLines[i].a * x) / badLines[i].b;
					assert(Abs(badLines[i].eval(x, y)) < eps);
					if(badLines[i].b > 0)
						y -= BUBEN;
					else
						y += BUBEN;
					//assert(badLines[i].eval(x, y) < 0);
					bool currentOk = true;
					for(int j = 0; j < m && currentOk; j++) {
						if(badLines[j].eval(x, y) > eps) {
							currentOk = false;
						}
					}
					if(currentOk)
						ok = true;
				}
			} else if(Abs(badLines[i].a) > eps) {
				
				for(int it = 0; it <= 1; it++) {
					ld y = getRand(it == 0);
					ld x = (-badLines[i].c - badLines[i].b * y) / badLines[i].a;
					assert(Abs(badLines[i].eval(x, y)) < eps);
					if(badLines[i].a > 0)
						x -= BUBEN;
					else
						x += BUBEN;
					//assert(badLines[i].eval(x, y) < 0);
					bool currentOk = true;
					for(int j = 0; j < m && currentOk; j++) {
						if(badLines[j].eval(x, y) > eps) {
							currentOk = false;
						}
					}
					if(currentOk)
						ok = true;
						x = -x;
						y = -y;
				}
			} else {
				assert(false);
			}
		}
	}
	//printf("RESULT: %d\n", ok);
	return ok;
}

bool solve() {
	srand(22);
	scanf("%d", &n);
	if(n == 0)
		return false;
	int maxSpeed = 1;
	for(int i = 0; i < n; i++) {
		scanf("%d%d%d", &points[i].first, &points[i].second, &speeds[i]);
		maxSpeed = max(maxSpeed, speeds[i]);
	}
	for(int i = 0; i < n; i++) {
		if(speeds[i] < maxSpeed) {
			printf("0");
		} else {
			if(check(i, maxSpeed)) {
				printf("1");
			} else {
				printf("0");
			}
		}
	}
	printf("\n");
	return true;
}

int main() {
	while(solve()) ;
	return 0;
}