import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Scanner;


public class Main {
	static double sqr(double a) {
		return a*a;
	}
	
	static boolean doubleEqual(double a, double b) {
		return Math.abs(a-b) < 1e-9;
	}
	
	static boolean doubleLessOrEqual(double a, double b) {
		return a<b || doubleEqual(a, b);
	}
	
	static boolean doubleLess(double a, double b) {
		return a<b && !doubleEqual(a, b);
	}
	
	static boolean doubleGreaterOrEqual(double a, double b) {
		return a>b || doubleEqual(a, b);
	}
	
	static boolean doubleGreater(double a, double b) {
		return a>b && !doubleEqual(a, b);
	}
	
	static double mySqrt(double a) {
		if (doubleLess(a, 0)) {
			throw new RuntimeException("sqrt(-1)");
		}
		if (a<0) return 0;
		return Math.sqrt(a);
	}
	
	static class Point {
		public double x;
		public double y;
		public int index;
		
		public Point(double x, double y, int index) {
			this.x = x;
			this.y = y;
			this.index = index;
		}
		
		public Point(int index) {
			this(0, 0, index);
		}
		
		public void scan(Scanner scanner) {
			x = scanner.nextDouble();
			y = scanner.nextDouble();
		}
		
		public void print(PrintWriter printWriter) {
			printWriter.print(x);
			printWriter.print(' ');
			printWriter.println(y);
		}
		
		public Point add(Point p) {
			return new Point(x + p.x, y + p.y, index);
		}
		
		public Point sub(Point p) {
			return new Point(x - p.x, y - p.y, index);
		}
		
		public Point minus() {
			return new Point(-x, -y, index);
		}
		
		public Point mul(double k) {
			return new Point(x*k, y*k, index);
		}
		
		
		public Point div(double k) {
			return new Point(x/k, y/k, index);
		}
		
		public double scalarProduct(Point p) {
			return x*p.x + y*p.y;
		}
		
		public double vectorProduct(Point p) {
			return x*p.y - y*p.x;
		}
		
		public double length() {
			return mySqrt(this.scalarProduct(this));
		}
		
		public double distTo(Point p) {
			return this.sub(p).length();
		}
		
		/** distance from this point to line */
		public double distTo(Point A, Point B) {
			double d = A.distTo(B);
			if (doubleEqual(d, 0)) {
				throw new RuntimeException("A = B");
			}
			double s = this.sub(A).vectorProduct(this.sub(B));
			return Math.abs(s) / d;
		}
		
		/** length of vector to k */
		public Point normalize(double k) {
			double len = length();
			if (doubleEqual(len,  0)) {
				if (doubleEqual(k, 0)) {
					return new Point(index);
				}
				throw new RuntimeException("zero-size vector");
			}
			return this.mul(k/len);
		}
		
		public Point normalize() {
			return normalize(1);
		}
		
		/** projection from this point to line */
		public Point getH(Point A, Point B) {
			Point C = this;
			Point v = B.sub(A);
			Point u = C.sub(A);
			double k = v.scalarProduct(u) / v.length();
			v = v.normalize(k);
			Point H = A.add(v);
			return H;
		}
		
		/** 90 degrees counterclockwise */
		public Point rotate() {
			return new Point(-y, x, index);
		}
		
		/** counterclockwise */
		public Point rotate(double alpha) {
			return rotate(Math.cos(alpha), Math.sin(alpha));
		}
		
		public Point rotate(double cosa, double sina) {
			Point v = this;
			Point u = v.rotate();
			Point w = v.mul(cosa).add(u.mul(sina));
			return w;
		}
		
		public boolean isZero() {
			return doubleEqual(x, 0) && doubleEqual(y, 0);
		}
		
		public boolean isOnLine(Point A, Point B) {
			return doubleEqual(A.sub(this).vectorProduct(B.sub(this)), 0);
		}
		
		public boolean isInSegment(Point A, Point B) {
			return isOnLine(A, B) && doubleLessOrEqual(A.sub(this).scalarProduct(B.sub(this)), 0);
		}
		
		public boolean isInSegmentStrictly(Point A, Point B) {
			return isOnLine(A, B) && doubleLess(A.sub(this).scalarProduct(B.sub(this)), 0);
		}
		
		/** angle between this and OX */
		public double getAngle() {
			return Math.atan2(y, x);
		}
		
		public double getAngle(Point u) {
			Point v = this;
			return Math.atan2(v.vectorProduct(u), v.scalarProduct(u));
		}
	}
	
	/** of line (A, B) and line(C, D) */
	static Point getIntersection(Point A, Point B, Point C, Point D) {
		Point v = B.sub(A);
		double s1 = C.sub(A).vectorProduct(D.sub(A));
		double s2 = D.sub(B).vectorProduct(C.sub(B));
		double s = s1 + s2;
		if (doubleEqual(s, 0)) {
			if (!A.isOnLine(C, D)) {
				return null; //intersection is empty
			}
			return null; // more then one point in intersection
		}
		v = v.div(s);
		v = v.mul(s1);
		return A.add(v);
	}
	
	static Point getSegmentsIntersection(Point A, Point B, Point C, Point D) {
		Point O = getIntersection(A, B, C, D);
		if (O == null) return null;
		if (O.isInSegment(A, B) && O.isInSegment(C, D)) return O;
		return null;
	}
	
	static double getTriangleArea(Point A, Point B, Point C) {
		double Al = A.sub(B).length();
		double Bl = B.sub(C).length();
		double Cl = C.sub(A).length();
		//System.out.println(Al+" "+Bl+" "+Cl);
		double P = (Al+Bl+Cl)/2;
		return mySqrt(P*(P-Al)*(P-Bl)*(P-Cl));
	}
	
	static boolean isPointInTriangle(Point P, Point A, Point B, Point C) {
		return doubleEqual(
				getTriangleArea(A, B, C),
				getTriangleArea(A, B, P) + getTriangleArea(A, P, C) + getTriangleArea(P, B, C));
	}
	
	static ArrayList<Point> vobl(ArrayList<Point> points) {
		if (points.size() <= 3) {
			return points;
		}
		
		ArrayList<Point> ob = new ArrayList<Point>();
		
		int left = 0;
		for (int i=0; i<points.size(); ++i) {
			if (doubleGreater(points.get(left).x, points.get(i).x)) {
				left = i;
			} else if (doubleEqual(points.get(left).x, points.get(i).x)){
				if (doubleGreater(points.get(left).y, points.get(i).y)) {
					left = i;
				}
			}
		}
		
		ob.add(points.get(left));
		Point i0 = points.get(left);
		Point i = i0;
		
		Point prevpryamaya = new Point(1, 0, -1);
		
		while (true) {
			double angle = Double.MAX_VALUE;
			double curlen = Double.MAX_VALUE;
			Point p = null;
			for (Point point : points) {
				if (point != i) {
					double curangle = point.sub(i).getAngle(prevpryamaya);
					if (doubleLess(curangle, angle)) {
						angle = curangle;
						p = point;
						curlen = p.sub(i).length();
					} else if (doubleEqual(curangle, angle)) {
						double trylen = point.sub(i).length();
						//System.out.println(trylen+" "+curlen);
						if (doubleLess(trylen, curlen)) {
							curlen = trylen;
							angle = curangle;
							p = point;
						}
					}
				}
			}
			prevpryamaya = p.sub(i);
			i = p;
			if (i==i0) break;
			ob.add(i);
		}
		return ob;
	}
	
	static public void main(String... args) {
		Scanner in = new Scanner(System.in);
		/*if(true) {
			int n = in.nextInt();
			ArrayList<Point> p = new ArrayList<Point>();
			for (int i=0;i<n;++i) {
				p.add(new Point(in.nextInt(), in.nextInt(), i));
			}
			p = vobl(p);
			System.out.println(p.size());
			for (Point pp : p) {
				System.out.println(pp.x+" "+pp.y);
			}
		}*/
		while (true) {
			int n = in.nextInt();
			if (n==0) return;
			int[]x=new int[n];
			int[]y=new int[n];
			int[]v=new int[n];
			int maxv = -1;
			for (int i=0;i<n;++i) {
				x[i]=in.nextInt();
				y[i]=in.nextInt();
				v[i]=in.nextInt();
				if (maxv < v[i]) maxv = v[i];
			}
			ArrayList<Point> points = new ArrayList<Point>();
			for (int i=0;i<n;++i) {
				if (v[i]==maxv) {
					points.add(new Point(x[i], y[i], i));
				}
			}
			points = vobl(points);
			boolean[] isinf = new boolean[n];
			Arrays.fill(isinf, false);
			for (Point p : points) {
				isinf[p.index] = true;
			}
			StringBuilder b = new StringBuilder(n);
			for (int i=0;i<n;++i) b.append(isinf[i]?'1':'0');
			System.out.println(b);
		}
	}
}
