#include <iostream>
#include <algorithm>
#include <cassert>

using namespace std;

struct point_t {
    int x, y, v, number;
};

ostream &operator << (ostream &out, point_t const &a) {
    out << "(" << a.x << ',' << a.y << ',' << a.number << ")";
    return out;
}

bool cmp(point_t const &a, point_t const &b) {
    return a.x < b.x || (a.x == b.x && a.y < b.y);
}
bool operator == (point_t const &a, point_t const &b) {
    return a.x == b.x && a.y == b.y && a.v == b.v;
}

int mult(point_t const &a, point_t const &b, point_t const &c) {
    return (b.x - a.x) * (c.y - b.y) - (b.y - a.y) * (c.x - b.x);
}

int n, v;
vector<point_t> points, up, down, buffer;
vector<int> answer;

void convex_hull() {
    buffer.clear();
    up.clear();
    down.clear();
    buffer.reserve(points.size());
    for (int i = 0; i < (int) points.size(); ++i) {
        if (points[i].v == v) {
            buffer.push_back(points[i]);
        }
    }
    if (buffer.size() <= 2) {
        for (int i = 0; i < (int) buffer.size(); ++i) {
            answer[buffer[i].number] = true;
        }
        return;
    }
    sort(buffer.begin(), buffer.end(), cmp);
    up.push_back(buffer[0]);
    down.push_back(buffer[0]);
    for (int i = 1; i < (int) buffer.size(); ++i) {
        if (i == buffer.size() - 1 || mult(buffer[0], buffer[i], buffer.back()) <= 0) {
            while (up.size() >= 2 && mult(up[up.size() - 2], up[up.size() - 1], buffer[i]) > 0)
                up.pop_back();
            up.push_back(buffer[i]);
        }
        if (i == buffer.size() - 1 || mult(buffer[0], buffer[i], buffer.back()) >= 0) {
            while (down.size() >= 2 && mult(down[down.size() - 2], down[down.size() - 1], buffer[i]) < 0)
                down.pop_back();
            down.push_back(buffer[i]);
        }
    }
#define DEBUG_
#ifdef DEBUG
    cout << "up: ";
    for (int i = 0; i < (int) up.size(); ++i)
        cout << up[i] << ' ';
    cout << endl;
    cout << "down: ";
    for (int i = 0; i < (int) down.size(); ++i)
        cout << down[i] << ' ';
    cout << endl;
#endif
    for (int i = 0; i < (int) up.size(); ++i)
        answer[up[i].number] = true;
    for (int i = 0; i < (int) down.size(); ++i)
        answer[down[i].number] = true;
}

int main() {
    ios_base::sync_with_stdio(false);
    while (cin >> n) {
        if (n == 0)
            break;
        points.resize(n);
        for (int i = 0; i < n; ++i) {
            cin >> points[i].x >> points[i].y >> points[i].v;
            points[i].number = i;
        }
        v = -1;
        for (int i = 0; i < (int) points.size(); ++i) {
            v = max(v, points[i].v);
        }
        if (v == 0) {
            for (int i = 0; i < n; ++i) {
                cout << 0;
            }
            cout << endl;
            continue;
        }
        answer.resize(n);
        for (int i = 0; i < (int) answer.size(); ++i)
            answer[i] = false;
        convex_hull();
        for (int i = 0; i < n; ++i) {
            for (int j = i + 1; j < n; ++j) {
                if (points[i] == points[j]) {
                    answer[i] = answer[j] = false;
                }
            }
        }
        for (int i = 0; i < n; ++i) {
            cout << answer[i];
        }
        cout << endl;
    }
    return 0;
}
