#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <iostream>
#include <string>
#include <vector>
#include <memory.h>
#include <algorithm>
#include <map>
#include <set>
#include <queue>

using namespace std;

#define fore(i, b, e) for (int i = (int)b; i <= (int)e; i++)
#define forn(i, n) for (int i = 0; i < (int)n; i++)
#define fi first
#define se second
#define pii pair <int, int>
#define mp make_pair
#define i64 long long
#define li long long
#define vi vector <int>

#define DEBUG false

const int maxn = 505;

const int inf = 1e9;

bool answer[maxn];

struct Point2
{
	double x, y;
	Point2(double _x, double _y) : x(_x), y(_y) {}
};

struct Line
{
	int a, b, c;
	Line(){}
	Line(int _a, int _b, int _c) : a(_a), b(_b), c(_c) {}
	Point2 intersect(Line an)
	{
		double y = (double)(an.c * a - c * an.a) / (double)(b * an.a - a * an.b);
		double x = (double)(an.c * b - c * an.b) / (double)(a * an.b - b * an.a);
		return Point2(x, y);
	}
	void print()
	{
		printf("(%d %d %d)\n", a, b, c);
	}
	bool parallel(Line an)
	{
		return a * an.b == b * an.a;
	}
	Point2 get_point()
	{
		if (b != 0)
			return Point2(0.0, (double)(-c) / b);
		else return Point2((double)(-c) / a, 0.0);
	}
};

bool operator == (Line first, Line second)
{
	return first.a == second.a && first.b == second.b && first.c == second.c;
}

struct Point
{
	int x, y;
	Point(int _x, int _y) : x(_x), y(_y) {}
	int get_type()
	{
		if (y > 0)
			return 0;
		return(y == 0 && x >= 0 ? 0 : 1);
	}
	int operator % (Point an)
	{
		return x * an.y - y * an.x;
	}
};

const double eps = 1.0e-9;

bool operator < (Line l1, Line l2)
{
	Point v1(l1.a, l1.b);
	Point v2(l2.a, l2.b);
	if (v1.get_type() != v2.get_type())
		return v1.get_type() == 0;
	int pr = v1 % v2;
	if (pr != 0)
		return pr > 0;
	Point2 P = l1.get_point();
	return(P.x * l2.a + P.y * l2.b + l2.c >= -eps);
}

int st[maxn];

inline void add(int j, vector <Line> & list, int & sz)
{
	if (DEBUG)
	{
		printf("\nadd ");
		list[j].print();
	}
	
	while(sz > 1)
	{
		Point2 P = list[st[sz - 1]].intersect(list[st[sz - 2]]);
		if (DEBUG)
		{
			printf("intersection is (%.5lf %.5lf) of \n", P.x, P.y);
			list[st[sz - 1]].print();
			printf("and ");
			list[st[sz - 2]].print();
		}
		if (P.x * list[j].a + P.y * list[j].b + list[j].c >= 0)
			break;
		sz--;
	}
	if (!list[st[sz - 1]].parallel(list[j]))
	{
		st[sz] = j;
		sz++;
	}
	//else st[sz - 1] = j;
	if (DEBUG)
	{
		printf("sz = %d\n", sz);
		forn(j, sz)
			printf("%d ", st[j]);
		printf("\n");
	}
}

Line bounds[4];

inline bool check_intersection(vector <Line> & list)
{
	if (DEBUG)
		printf("================================\n");
	sort(list.begin(), list.end());
	if (DEBUG)
	{
		forn(j, list.size())
		{
			printf("list[%d] = ", j);
			list[j].print();
		}
	}
	st[0] = 0;
	int cur = 1;
	while(list[0].parallel(list[cur]))
		cur++;
	//st[0] = cur - 1;
	st[1] = cur;
	int sz = 2;
	fore(j, cur + 1, list.size() - 1)
	{
		add(j, list, sz);
	}
	forn(j, list.size())
		add(j, list, sz);
	forn(j, sz)
	{
		forn(h, 4)
			if (list[st[j]] == bounds[h])
				return true;
	}
	return false;
}

int x[maxn];
int y[maxn];
int v[maxn];

int main()
{
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
	bounds[0] = Line(1, 0, inf);
	bounds[1] = Line(-1, 0, inf);
	bounds[2] = Line(0, 1, inf);
	bounds[3] = Line(0, -1, inf);
	while(true)
	{
		int n;
		scanf("%d", &n);
		if (n == 0)
			break;
		int maxv = 0;
		forn(j, n)
		{
			scanf("%d%d%d", &x[j], &y[j], &v[j]);
			maxv = max(maxv, v[j]);
		}
		memset(answer, false, sizeof(answer));
		forn(j, n) if (v[j] == maxv)
		{
			vector <Line> list;
			forn(h, 4)
				list.push_back(bounds[h]);
			forn(i, n) if (v[i] == maxv && i != j)
			{
				int xm = x[i] + x[j];
				int ym = y[i] + y[j];
				int vx = x[j] - x[i];
				int vy = y[j] - y[i];
				list.push_back(Line(2 * vx, 2 * vy, -vx * xm - vy * ym));
			}
			answer[j] = check_intersection(list);
		}
		forn(j, n)
			printf("%d", answer[j]);
		printf("\n");
	}

}