#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <iostream>
#include <string>
#include <vector>
#include <memory.h>
#include <algorithm>
#include <map>
#include <set>
#include <queue>

using namespace std;

#define fore(i, b, e) for (int i = (int)b; i <= (int)e; i++)
#define forn(i, n) for (int i = 0; i < (int)n; i++)
#define fi first
#define se second
#define pii pair <int, int>
#define mp make_pair
#define i64 long long
#define li long long
#define vi vector <int>

#define DEBUG false

const int maxn = 505;

const i64 inf = 1e9;

bool answer[maxn];

struct Point2
{
	double x, y;
	Point2(){}
	Point2(double _x, double _y) : x(_x), y(_y) {}
};

struct Point
{
	i64 x, y, typ;
	Point(){}
	Point(i64 _x, i64 _y) : x(_x), y(_y)
	{
		if (y > 0)
			typ = 0;
		else typ = (y == 0 && x >= 0 ? 0 : 1);
	}
	inline i64 operator % (Point an)
	{
		return x * an.y - y * an.x;
	}
};

struct Line
{
	i64 a, b, c;
	Point2 point_on_line;
	Line(){}
	Line(i64 _a, i64 _b, i64 _c) : a(_a), b(_b), c(_c)
	{
		if (b != 0)
			point_on_line = Point2(0.0, (double)(-c) / b);
		else point_on_line = Point2((double)(-c) / a, 0.0);
	}
	Point2 intersect(Line an)
	{
		double y = (double)(an.c * a - (i64)c * an.a) / (double)(b * an.a - (i64)a * an.b);
		double x = (double)(an.c * b - (i64)c * an.b) / (double)(a * an.b - (i64)b * an.a);
		return Point2(x, y);
	}
	void print()
	{
		printf("(%d %d %d)\n", a, b, c);
	}
	bool parallel(Line an)
	{
		return a * an.b == b * an.a;
	}
	bool check_point(Point P)
	{
		return (i64)a * P.x + (i64)b * P.y + c >= 0;
	}
};

bool operator == (Line first, Line second)
{
	return first.a == second.a && first.b == second.b && first.c == second.c;
}



const double eps = 1.0e-9;

inline bool operator < (const Line & l1, const Line & l2)
{
	Point v1(l1.a, l1.b);
	Point v2(l2.a, l2.b);
	if (v1.typ != v2.typ)
		return v1.typ == 0;
	i64 pr = v1 % v2;
	if (pr != 0)
		return pr > 0;
	Point2 P = l1.point_on_line;
	return(P.x * l2.a + P.y * l2.b + l2.c >= -eps);
}

int st[maxn * maxn * 2];

inline void add(int j, vector <Line> & list, int & sz)
{
	/*if (DEBUG)
	{
		printf("\nadd ");
		list[j].print();
	}*/
	
	while(sz > 1)
	{
		Point2 P = list[st[sz - 1]].intersect(list[st[sz - 2]]);
		/*if (DEBUG)
		{
			printf("intersection is (%.5lf %.5lf) of \n", P.x, P.y);
			list[st[sz - 1]].print();
			printf("and ");
			list[st[sz - 2]].print();
		}*/
		if (P.x * list[j].a + P.y * list[j].b + list[j].c >= 0)
			break;
		sz--;
	}
	if (!list[st[sz - 1]].parallel(list[j]))
	{
		st[sz] = j;
		sz++;
	}
	//else st[sz - 1] = j;
	/*if (DEBUG)
	{
		printf("sz = %d\n", sz);
		forn(j, sz)
			printf("%d ", st[j]);
		printf("\n");
	}*/
}

Line bounds[4];

inline bool check_intersection(vector <Line> & list)
{
	if (DEBUG)
		printf("================================\n");
	sort(list.begin(), list.end());
	/*if (DEBUG)
	{
		forn(j, list.size())
		{
			printf("list[%d] = ", j);
			list[j].print();
		}
	}*/
	st[0] = 0;
	int cur = 1;
	while(list[0].parallel(list[cur]))
		cur++;
	//st[0] = cur - 1;
	st[1] = cur;
	int sz = 2;
	fore(j, cur + 1, list.size() - 1)
	{
		add(j, list, sz);
	}
	forn(j, list.size())
		add(j, list, sz);
	forn(j, sz)
	{
		forn(h, 4)
			if (list[st[j]] == bounds[h])
				return true;
	}
	return false;
}

i64 x[maxn];
i64 y[maxn];
i64 v[maxn];
double minn[maxn];
double maxx[maxn];
Point bound_points[4];

void process(Line L, int bound)
{
		if (bounds[bound].parallel(L))
		{
			if (!L.check_point(bound_points[bound]))
				minn[bound] = -inf - 1;
			return;
		}
		Point2 P = bounds[bound].intersect(L);
		double c;
		if ( bound <= 1)
			c = P.y;
		else c = P.x;
		if (c <= -inf)
		{
			if (L.check_point(bound_points[bound]))
				return;
			else minn[bound] = -inf - 1;
		}
		else if (c >= inf)
		{
			if (L.check_point(bound_points[bound]))
				return;
			else minn[bound] = -inf - 1;
		}
		else
		{
			if (L.check_point(bound_points[bound]))
			{
				minn[bound] = min(minn[bound], c);
				
			}
			else
			{
				maxx[bound] = max(maxx[bound], c);  
			}
		}
	
}

int main()
{
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
	bounds[0] = Line(1, 0, inf);
	bounds[1] = Line(-1, 0, inf);
	bounds[2] = Line(0, 1, inf);
	bounds[3] = Line(0, -1, inf);
	bound_points[0] = bound_points[2] = Point(-inf, -inf);
	bound_points[1] = Point(inf, -inf);
	bound_points[3] = Point(-inf, inf);
	while(true)
	{
		int n;
		
		scanf("%d", &n);
		if (n == 0)
			break;
		//n = 500;
		
		i64 maxv = 0;
		forn(j, n)
		{
			scanf("%lld%lld%lld", &x[j], &y[j], &v[j]);
			//x[j] = rand() % 5;
			//y[j] = rand() % 5;
			//v[j] = 3;
			maxv = max(maxv, v[j]);
		}
		memset(answer, false, sizeof(answer));
		forn(j, n) if (v[j] == maxv)
		{
			forn(h, 4)
			{
				maxx[h] = -inf;
				minn[h] = inf;
			}
			forn(i, n) if (v[i] == maxv && i != j)
			{
				i64 xm = x[i] + x[j];
				i64 ym = y[i] + y[j];
				i64 vx = x[j] - x[i];
				i64 vy = y[j] - y[i];
				forn(h, 4)
				{
					/*if (i == 8 && h == 3)
					{
						int jj = 0;
					}*/
					process(Line(2 * vx, 2 * vy, -vx * xm - vy * ym), h);
					//if (h == 3)
					//	printf("after i = %d minn = %.5lf maxx = %.5lf\n", i, minn[3], maxx[3]);
				}
			}
			forn(h, 4) if (minn[h] - maxx[h] >= -eps)
			{
				answer[j] = true;
				break;
			}
		}
		forn(j, n)
			printf("%d", answer[j]);
		printf("\n");
	}

}