#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <cassert>
#include <ctime>
#include <cstring>
#include <algorithm>
#include <iostream>
#include <set>
#include <map>
#include <vector>
#include <queue>
#include <deque>
using namespace std;
#define pb push_back
#define mp make_pair
#define sc second
#define fs first
#define int64 long long
#define ldb long double
#define sz(a) ((int) (a).size())
#define eprintf(...) fprintf(stderr, __VA_ARGS__)

const int size = 200 * 1000 + 100;
const double eps = 1e-10;
const double pi = acos(-1.0);

inline double sqr(double x) {
	return x * x;
}

struct point {
	double x, y;
	point (double x_ = 0.0, double y_ = 0.0) : x(x_), y(y_) {}

	double dist(const point& p) const {
		return sqrt(sqr(p.x - x) + sqr(p.y - y));
	}

	double len() const {
		return sqrt(sqr(x) + sqr(y));
	}
};

double smult(const point& a, const point& b) {
	return a.x * b.x + a.y * b.y;
}

double vmult(const point& a, const point& b) {
	return a.x * b.y - a.y * b.x;
}

struct line {
	double a, b, c;
	line(double a_ = 1.0, double b_ = 0.0, double c_ = 0.0) : a(a_), b(b_), c(c_) {
		norm();
	}

	line(const point& p1, const point& p2) {
		a = p2.y - p1.y;
		b = p1.x - p2.x;
		c = - a * p1.x - b * p1.y;

		norm();
	}

	void norm() {
		double k = sqrt(sqr(a) + sqr(b));

//		assert(k > eps);

		a /= k;
		b /= k;
		c /= k;
	}

	double dist(const point& p) const {
		return a * p.x + b * p.y + c;
	}
};

bool cross(const line& l1, const line& l2, point& p) {
	double d = l1.a * l2.b - l1.b * l2.a;
	if (fabs(d) < eps)
		return false;

	p.x = (l1.b * l2.c - l1.c * l2.b) / d;
	p.y = (l2.a * l1.c - l1.a * l2.c) / d;

	//assert(fabs(l1.dist(p)) < eps);
	//assert(fabs(l2.dist(p)) < eps);

	return true;
}

double curang;
line curline;
line segline[size];

struct cmp {
	bool operator ()(const int& a, const int& b) {
		//line h(-sin(curang), cos(curang), 0.0);
		point p1, p2;
		//assert(cross(segline[a], curline, p1));
		//assert(cross(segline[b], curline, p2));
		cross(segline[a], curline, p1);
		cross(segline[b], curline, p2);

		return p1.len() < p2.len();
	}
};

bool eqdouble(const double& a, const double& b) {
	return fabs(a - b) < eps;
}

bool lessdouble(const double& a, const double& b) {
	return a < b - eps;
}

int n;
int xc, yc;
int x[size];
int y[size];
point pts[size];
double ang[size];

set <int, cmp> segs;
bool used[size];
vector <int> action[size];
line dir[size];
line hdir[size];

bool onseg(const point& a, const point& b, point& p) {
	return a.dist(b) - a.dist(p) - b.dist(p) > -eps;
}

int main() {
//	assert(freopen("input.txt", "r", stdin));
//	assert(freopen("output.txt", "w", stdout));

	int tc;
	scanf("%d", &tc);
	for (int tnum = 0; tnum < tc; tnum++) {
		segs.clear();
		scanf("%d%d", &xc, &yc);
		
		scanf("%d", &n);
		if (n == 0)
			break;
		for (int i = 0; i < n; i++) {
			scanf("%d%d", &x[i], &y[i]);
			x[i] -= xc;
			y[i] -= yc;
		}

		vector <double> angs;
		angs.pb(0.0);
		angs.pb(2 * pi);

		for (int i = 0; i < n; i++) {
			pts[i] = point(x[i], y[i]);
			ang[i] = atan2(y[i] * 1.0, x[i] * 1.0);
			while (ang[i] < 0)
				ang[i] += 2 * pi;
			angs.pb(ang[i]);
		}

		sort(angs.begin(), angs.end());

		for (int i = 0; i < n; i++) {
			segline[i] = line(pts[i], pts[(i + 1) % n]);
		}

		angs.resize(unique(angs.begin(), angs.end(), eqdouble) - angs.begin());
		
		for (int i = 0; i < n + 2; i++)
			action[i].clear();
		
		for (int i = 0; i < n; i++) {
			int ps1 = lower_bound(angs.begin(), angs.end(), ang[i], lessdouble) - angs.begin();
			int ps2 = lower_bound(angs.begin(), angs.end(), ang[(i + 1) % n], lessdouble) - angs.begin();

			if (ps1 != ps2) {
				action[ps1].pb(i);
				action[ps2].pb(i);
			}
		}

		int m = angs.size();
		for (int i = 0; i < m; i++) {
			dir[i] = line(-sin(angs[i]), cos(angs[i]), 0.0);
			double hang = (angs[i] + angs[(i + 1) % m]) / 2.0;
			hdir[i] = line(-sin(hang), cos(hang), 0.0);
		}

		double ans = 0.0;
		curang = (angs[0] + angs[1]) / 2.0;
		curline = hdir[0];

		for (int i = 0; i < n; i++) {
			point p;
			if (cross(segline[i], curline, p)) {
				if (smult(p, point(cos(curang), sin(curang))) > 0 && onseg(pts[i], pts[(i + 1) % n], p)) {
					segs.insert(i);
					used[i] = true;
				}
			}
		}

		for (int i = 0; i < m - 1; i++) {
			int c = *segs.begin();

			point p1, p2;
			//assert(cross(dir[i], segline[c], p1));
			cross(dir[i], segline[c], p1);
			//assert(cross(dir[i + 1], segline[c], p2));
			cross(dir[i + 1], segline[c], p2);

			ans += vmult(p1, p2);

			vector <int> toadd;
			vector <int> todelete;
			for (int j = 0; j < action[i + 1].size(); j++) {
				if (used[action[i + 1][j]])
					todelete.pb(action[i + 1][j]);
				else
					toadd.pb(action[i + 1][j]);
				used[action[i + 1][j]] ^= 1;
			}

			for (int j = 0; j < (int) todelete.size(); j++)
				segs.erase(todelete[j]);
			if (i < m - 2) {
				curang = (angs[i + 1] + angs[i + 2]) / 2.0;
				curline = hdir[i + 1];
			
				for (int j = 0; j < (int) toadd.size(); j++)
					segs.insert(toadd[j]);
			}

		}

		printf("%.10lf\n", fabs(ans) / 2.0);
	}

	return 0;
}