#include <iostream> 
#include <cstdio> 
#include <map> 
#include <set> 
#include <algorithm> 
#include <cstdlib> 
#include <cstring>
#include <cassert>
#include <utility>
#include <vector>
#include <string>
#include <queue>
#include <fstream> 
#include <iomanip> 
#include <sstream> 
#include <cmath> 
#include <ctime> 
#include <cctype> 
#include <deque> 

#define pb push_back
#define mp make_pair

using namespace std;

typedef long long ll;
typedef unsigned long long ull;
typedef long long ld;
typedef pair< int, int > pii;
typedef vector< int > vi;

template <class T> inline void updMax(T &x, const T &other) { if (x < other) x = other; }
template <class T> inline void updMin(T &x, const T &other) { if (other < x) x = other; }
template <class T> inline T sqr(const T &x) { return x * x; } 

struct Point
{
	ld x, y;
	Point(ld x_ = 0., ld y_ = 0.) : x(x_), y(y_) {}
	Point operator+(const Point &lhs) const {
		return Point(x + lhs.x, y + lhs.y);
	}
	Point operator-(const Point &lhs) const {
		return Point(x - lhs.x, y - lhs.y);
	}
	ld operator*(const Point &lhs) const {
		return x * lhs.x + y * lhs.y;
	}
	ld operator^(const Point &lhs) const {
		return x * lhs.y - y * lhs.x;
	}
	friend istream& operator>>(istream &in, Point &p)
	{
		return in >> p.x >> p.y;
	}
	ld sqlen() const
	{
		return x * x + y * y;
	}
	bool operator<(const Point &lhs) const {
		return x < lhs.x || (x == lhs.x && y < lhs.y);
	}
};

/*const ld INF = 1e12;
const ld EPS = 1e-9;
#ifndef M_PI
const ld M_PI = atan(1.) * 4;
#endif*/

typedef pair< Point, Point > Seg;

bool cmp(const Point &a, const Point &b)
{
	ld vec = a ^ b;
	return (vec > 0 || vec == 0 && a.sqlen() < b.sqlen());
}


vector< Point >
getConvexHull(vector< Point > &arr)
{
	int cnt = int(arr.size());
	int id = 0;
	vector< Point > res;
	for (int i = 0; i < cnt; ++i) {
		if (arr[i] < arr[id]) {
			id = i;
		}
	}
	Point null = arr[id];
	vector< Point > tmp;
	for (int i = 0; i < cnt; ++i) {
		arr[i] = arr[i] - null;
		if (arr[i].sqlen() > 0) {
			tmp.push_back(arr[i]);
		}
	}
	sort(tmp.begin(), tmp.end(), cmp);
	vector< Point > stack;
	int st = 1;
	stack.push_back(Point());
	int tmps = int(tmp.size());
	for (int i = 0; i < tmps; ++i) {
		while (st > 1) {
			if (((stack[st - 1] - stack[st - 2]) ^ (tmp[i] - stack[st - 1])) > 0) {
				break;
			}
			--st;
			stack.pop_back();
		}
		++st;
		stack.push_back(tmp[i]);
	}
	for (int i = 0; i < st; ++i) {
		stack[i] = stack[i] + null;
	}
	return stack;
}

bool
check(const vector< Point > &ch, Point x)
{
	int chs = ch.size();
	if (chs == 1) {
		return (ch[0] - x).sqlen() == 0;
	}
	for (int i = 0; i < chs; ++i) {
		int id1 = i, id2 = (i + 1) % chs;
		if (((ch[id2] - ch[id1]) ^ (x - ch[id1])) == 0) {
			return true;
		}
	}
	return false;
}

bool
process()
{
	int n;
	cin >> n;
	if (!n) {
		return false;
	}
	vector< Point > allP(n);
	vector< int > v(n);
	vector< char > res(n, '0');
	for (int i = 0; i < n; ++i) {
		cin >> allP[i] >> v[i];
	}
	int maxV = *max_element(v.begin(), v.end());
	map< Point, int > pcnt;
	vector< Point > getV;
	for (int i = 0; i < n; ++i) {
		if (v[i] == maxV) {
			pcnt[allP[i]]++;
			getV.push_back(allP[i]);
		}
	}
	vector< Point > ch = getConvexHull(getV);
	for (int i = 0; i < n; ++i) {
		if (maxV && v[i] == maxV && pcnt[allP[i]] == 1 && check(ch, allP[i])) {
			res[i] = '1';
		}
	}
	for (int i = 0; i < n; ++i) {
		cout << res[i];
	}
	cout << '\n';
	return true;
}

int main()
{
	//freopen("input.txt", "r", stdin); freopen("output.txt", "w", stdout);
	//freopen(".in", "r", stdin); freopen(".out", "w", stdout);
	
	ios::sync_with_stdio(false); 
	
	while (process());
	

	return 0;
}