#include <stdio.h>
//#include <windows.h>
#include <math.h>
#include <string.h>
#include <memory.h>
#include <stdlib.h>
#include <ctype.h>
#include <vector>
#include <string>
#include <map>
#include <set>
#include <algorithm>
#include <iostream>
using namespace std;
typedef long long LL;
typedef pair<int, int> pii;
typedef vector<int> vint;
typedef vector<string> vstr;
#define FOR(i,a,b) for(int i=(a);i<(b);i++)
#define ROF(i,a,b) for(int i=(b)-1;i>=a;i--)
#define ALL(v) v.begin(),v.end()
const int INF = 0x7FFFFFFF;

const double PI = 3.1415926535897932384626433832795;
const int MAXN = 131072;

struct Line {
  double angle;
  double dist;

  Line() {}
  Line(double a, double d)
    : angle(a), dist(d)
  {}
  double get(double a) {
    if (fabs(a - angle) > PI / 2 - 1e-6) {
      return 1e+9;
    }
    return dist / cos(a - angle);
  }
};
bool operator < (Line const& a, Line const& b) {
  return a.angle < b.angle - 1e-6;
}
bool operator == (Line const& a, Line const& b) {
  return fabs(a.angle - b.angle) <= 1e-6;
}
Line intersect(Line const& a, Line const& b) {
  if (a.angle > b.angle) {
    return intersect(b, a);
  }
  double alpha = b.angle - a.angle;
  double phi = alpha - atan((a.dist - b.dist * cos(alpha)) / (b.dist * sin(alpha)));
  return Line(phi + a.angle, a.dist / cos(phi));
}

const int Step = 20;

struct LineData {
  vector<Line> lines;
  vector<Line> angles;
  vector<Line> temp;

  double left;
  double right;

  int limit;

  void init(double l, double r) {
    left = l;
    right = r;
    lines.clear();
    angles.clear();
    temp.clear();
    lines.push_back(Line((left + right) / 2, 1e+6));
    angles.push_back(Line(right, lines[0].get(right)));
    limit = 3;
  }

  void rebuild() {
//    cerr << "Rebuilding: " << lines.size() << "+" << temp.size() << endl;
//    double ang = (double(rand() % 1000) * 0.001) * (right - left) + left;
//    double old = get(ang);
    temp.insert(temp.end(), lines.begin(), lines.end());
    lines.clear();
    angles.clear();
    sort(temp.begin(), temp.end());
    temp.resize(unique(temp.begin(), temp.end()) - temp.begin());
    for (int i = 0; i < temp.size(); i++) {
      Line& line = temp[i];
      while (angles.size() && line.get(angles.back().angle) <= angles.back().dist) {
        angles.pop_back();
        lines.pop_back();
      }
      if (lines.size()) {
        angles.push_back(intersect(lines.back(), line));
      }
      lines.push_back(line);
    }
    angles.push_back(Line(right, lines.back().get(right)));
    temp.clear();
    limit = max(3, int(1 + sqrt((double) lines.size())));
//    double cur = get(ang);
//    if (fabs(cur - old) > 1e-3) {
//     printf("Bad\n");
//    }
//    cerr << "After: " << lines.size() << "+" << temp.size() << endl;
  }
  double get(double angle) {
    if (angle + 2 * PI < right) angle += 2 * PI;
    Line langle(angle - 1e-6, 1);
    int index = lower_bound(angles.begin(), angles.end(), langle) - angles.begin();
    double answer = lines[index].get(angle);
    for (int i = 0; i < temp.size(); i++) {
      Line& line = temp[i];
      answer = min(answer, line.get(angle));
    }
    return answer;
  }
  void add(Line line) {
    if (line.angle + PI < right) line.angle += 2 * PI;
    temp.push_back(line);
    if (temp.size() >= limit) {
      rebuild();
    }
  }
};

struct Segment {
  Line line;
  double left;
  double right;
  void init(double x1, double y1, double x2, double y2) {
    double nx = y2 - y1;
    double ny = -(x2 - x1);
    if (x1 * nx + y1 * ny < 0) {
      swap(x1, x2);
      swap(y1, y2);
      nx = -nx;
      ny = -ny;
    }
    line.angle = atan2(ny, nx);
    line.dist = (nx * x1 + ny * y1) / sqrt(nx * nx + ny * ny);
    left = atan2(y1, x1);
    right = atan2(y2, x2);
    if (right < 0) {
      if (left < 0) {
        left += 2 * PI;
      }
      right += 2 * PI;
    }
    //if (line.angle < 0) line.angle += 2 * PI;
  }
};

bool dcompare(double x, double y) {
  return fabs(x - y) < 1e-6;
}

struct SegmentTree {
  LineData tree[MAXN * 2];
  LineData points[MAXN];
  vector<double> angles;
  int n;

  void init() {
    FOR(i, 0, angles.size()) {
      if (angles[i] < 0) angles[i] += 2 * PI;
    }
    sort(angles.begin(), angles.end());
    angles.resize(unique(angles.begin(), angles.end(), dcompare) - angles.begin());
    n = angles.size() - 1;
    FOR(i, 0, n) {
      tree[i + MAXN].init(angles[i], angles[i + 1]);
    }
    FOR(i, n, MAXN) {
      tree[i + MAXN].init(angles[n], angles[n]);
    }
    ROF(i, 1, MAXN) {
      tree[i].init(tree[i + i].left, tree[i + i + 1].right);
    }
    FOR(i, 0, n + 1) {
      points[i].init(angles[i], angles[i]);
    }
  }

  void doadd(int i, Segment const& segment) {
    if (i >= MAXN || (tree[i].right - tree[i].left < 2 && segment.left < tree[i].left + 1e-6 && segment.right > tree[i].right - 1e-6)) {
      tree[i].add(segment.line);
      return;
    }
    if (segment.left < tree[i + i].right - 1e-6) {
      doadd(i + i, segment);
    }
    if (segment.right > tree[i + i + 1].left + 1e-6) {
      doadd(i + i + 1, segment);
    }
  }
  void add(Segment const& segment) {
    doadd(1, segment);
    points[lower_bound(angles.begin(), angles.end(), segment.left - 1e-8) - angles.begin()].add(segment.line);
    points[lower_bound(angles.begin(), angles.end(), segment.right - 1e-8) - angles.begin()].add(segment.line);
    if (segment.left < 0) {
      Segment temp(segment);
      temp.left += 2 * PI;
      temp.right += 2 * PI;
      doadd(1, temp);
      points[lower_bound(angles.begin(), angles.end(), temp.left - 1e-8) - angles.begin()].add(segment.line);
      points[lower_bound(angles.begin(), angles.end(), temp.right - 1e-8) - angles.begin()].add(segment.line);
    }
  }

  double get(double angle, double eps) {
    if (angle < -1e-8) angle += 2 * PI;
    int pos = lower_bound(angles.begin(), angles.end(), angle + eps - 1e-8) - angles.begin();
    double answer = 1e+9;
    if (fabs(angle + eps - angles[pos]) < 1e-8) {
      answer = points[pos].get(angle);
    }
    if (pos) pos--;
    for (pos += MAXN; pos; pos /= 2) {
      if (tree[pos].right - tree[pos].left < 2) {
        answer = min(answer, tree[pos].get(angle));
      }
    }
    return answer;
  }
};

SegmentTree tree;

void test() {
  tree.angles.clear();
  tree.angles.push_back(0);
  tree.angles.push_back(PI * 0.5);
  tree.angles.push_back(PI);
  tree.angles.push_back(PI * 1.5);
  tree.angles.push_back(PI * 2);
  vector<pair<double, double>> points;
  double px, py;
  cin >> px >> py;
  int n;
  cin >> n;
  FOR(i, 0, n) {
    double x, y;
    cin >> x >> y;
    points.push_back(make_pair(x - px, y - py));
    double angle = atan2(y - py, x - px);
    if (angle < 0) angle += 2 * PI;
    tree.angles.push_back(angle);
  }
  tree.init();
  FOR(i, 0, n) {
    Segment segment;
    int j = (i + 1) % n;
    segment.init(points[i].first, points[i].second, points[j].first, points[j].second);
    tree.add(segment);
  }
  double area = 0;
  FOR(i, 0, tree.angles.size()) {
    double a = tree.angles[i];
    double b = tree.angles[(i + 1) % tree.angles.size()];
    double da = tree.get(a, 1e-6);
    double db = tree.get(b, -1e-6);
    area += da * db * sin(b - a) / 2;
  }
  cout << fixed << area << "\n";
}

int main() {
  std::ios_base::sync_with_stdio(false);
  int T;
  cin >> T;
  cout.precision(6);
  FOR(i, 0, T) test();
  return 0;
}
