#include <iostream>
#include <algorithm>

using namespace std;

struct Point {
    int x, y, id;

    Point() {}

    Point(int x, int y): x(x), y(y), id(-1) {}

    bool operator<(const Point &p) const {
        return x < p.x || (x == p.x && (y < p.y || (y == p.y && id < p.id)));
    }

    Point operator-(const Point &p) const {
        return Point(x - p.x, y - p.y);
    }
};

const int MAXN = 505;
Point p[MAXN], q[MAXN];
int v[MAXN], m;
char ans[MAXN], bad[MAXN];

int cp(const Point &a, const Point &b) {
    return a.x * b.y - a.y * b.x;
}

int sqLen(const Point &p) {
    return p.x * p.x + p.y * p.y;
}

bool cmp(const Point &a, const Point &b) {
    int cpp = cp(a, b);
    return cpp > 0 || (cpp == 0 && sqLen(a) < sqLen(b));
}

bool cmpUn(const Point &a, const Point &b) {
    return a.x == b.x && a.y == b.y;
}

void buildCH() {
    sort(q, q + m);
    for(int i = 0; i < m; i++) {
        if((!i || (q[i].x != q[i - 1].x || q[i].y != q[i - 1].y)) &&
           (i == m - 1 || (q[i].x != q[i + 1].x || q[i].y != q[i + 1].y)))
            bad[q[i].id] = false;
        else
            bad[q[i].id] = true;
    }
    m = unique(q, q + m, cmpUn) - q;
    int h = 1;
    while(h < m) {
        int l = h;
        for(int i = h + 1; i < m; i++)
            if(cmp(q[i] - q[h - 1], q[l] - q[h - 1]))
                l = i;
        if(h > 1 && cmp(q[0] - q[h - 1], q[l] - q[h - 1]))
            break;
        swap(q[l], q[h]);
        h++;
    }
    for(int i = 0; i < h; i++)
        if(!bad[q[i].id])
            ans[q[i].id] = true;
}

int main() {
    ios_base::sync_with_stdio(false);
    while(true) {
        int n;
        cin >> n;
        if(!n)
            break;
        int maxv = 0;
        for(int i = 0; i < n; i++) {
            cin >> p[i].x >> p[i].y >> v[i];
            p[i].id = i;
            maxv = max(maxv, v[i]);
        }
        if(maxv == 0) {
            for(int i = 0; i < n; i++)
                cout << '0';
            cout << '\n';
            continue;
        }
        m = 0;
        for(int i = 0; i < n; i++)
            if(v[i] == maxv)
                q[m++] = p[i];
        for(int i = 0; i < n; i++)
            ans[i] = false;
        buildCH();
        for(int i = 0; i < n; i++)
            if(ans[i])
                cout << '1';
            else
                cout << '0';
        cout << '\n';
    }
    return 0;
}
