#include <cstdio>
#include <iostream>
#include <vector>
#include <algorithm>
#include <cstring>
#include <string>
#include <cmath>
#include <map>
#include <set>
#include <climits>
#include <cassert>
#include <cctype>
#include <queue>
#include <ctime>
#include <bitset>
using namespace std;

typedef long long ll;
typedef double dbl;
typedef long double ld;

#define mp make_pair
#define pb push_back
#define sz(x) (int)x.size()
#define all(x) x.begin(),x.end()
#define X first
#define Y second

const ll maxn = 200*1000 + 10;
const dbl eps = 1e-7;
const int mod = 1e9 + 9;

struct Point {
	int x, y;
	int pos;
	Point() {};
	Point(int x, int y, int pos) : x(x), y(y), pos(pos) {};

};

bool cmp (Point a, Point b) {
	return a.x < b.x || a.x == b.x && a.y < b.y;
}

bool cw (Point a, Point b, Point c) {
	return a.x*(b.y - c.y) + b.x*(c.y - a.y) + c.x*(a.y - b.y) <= 0;
}

bool ccw (Point a, Point b, Point c) {
	return a.x*(b.y - c.y) + b.x*(c.y - a.y) + c.x*(a.y - b.y) >= 0;
}

void convex_hull_greham(vector <Point> & a) {
	if (a.size() == 1) return;
	sort(all(a), cmp);
	Point p1 = a[0], p2 = a.back();
	vector <Point> up, down;
	up.pb(p1);
	down.pb(p1);
	for (int i = 1; i < sz(a); i++) {
		if (i == sz(a) - 1 || cw(p1, a[i], p2)) {
			while (sz(up) >= 2 && !cw(up[sz(up) - 2] ,up[sz(up) - 1], a[i]))
				up.pop_back();
			up.pb(a[i]);
		}
		if (i == sz(a) - 1 || ccw(p1, a[i], p2)) {
			while (sz(down) >= 2 && !ccw(down[sz(down) - 2], down[sz(down) - 1], a[i]))
				down.pop_back();
			down.pb(a[i]);
		}
	}
	a.clear();
	for (int i = 0; i < sz(up); i++)
		a.pb(up[i]);
	for (int i = sz(down) - 2; i > 0; i--)
		a.pb(down[i]);
}

int x[maxn], y[maxn], v[maxn];
vector<Point> points;
vector<Point> points_once;
int bad[maxn];

int main() {
#ifdef _MBCS
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif
	
	while (true) {
		int n;
		scanf("%d", &n);
		if (n == 0) break;
		int maxv = -INT_MAX;
		for (int i = 0; i < n; i++) {
			scanf("%d%d%d", &x[i], &y[i], &v[i]);
			maxv = max(maxv, v[i]);
			bad[i] = -1;
		}
		points.clear();
		for (int i = 0; i < n; i++)
			if (v[i] == maxv) {
				points.pb(Point(x[i], y[i], i));
			} else {
				bad[i] = 1;
			}
		
		points_once.clear();
		for (int i = 0; i < sz(points); i++) {
			if (bad[points[i].pos] == 1) continue;
			points_once.pb(points[i]);
			for (int j = i + 1; j < sz(points); j++) {
				if (mp(points[i].x, points[i].y) == mp(points[j].x, points[j].y)) {
					bad[points[i].pos] = 1;
					bad[points[j].pos] = 1;
				}
			}
		}

		convex_hull_greham(points_once);
		for (int i = 0; i < sz(points_once); i++) {
			if (bad[points_once[i].pos] != 1)
				bad[points_once[i].pos] = 0;
		}

		for (int i = 0; i < n; i++) {
			if (bad[i] == 0) printf("1");
			else printf("0");
		}
		puts("");
	}
	return 0;
}