#include <cstdio>
#include <iostream>
#include <vector>
#include <algorithm>
#include <cstring>
#include <string>
#include <cmath>
#include <map>
#include <set>
#include <climits>
#include <cassert>
#include <cctype>
#include <queue>
#include <ctime>
#include <bitset>
using namespace std;

typedef long long ll;
typedef double dbl;
typedef long double ld;

#define mp make_pair
#define pb push_back
#define sz(x) (int)x.size()
#define all(x) x.begin(),x.end()
#define X first
#define Y second

const ll maxn = 200*1000 + 10;
const dbl eps = 1e-7;
const int mod = 1e9 + 9;

bool is_equal(dbl a, dbl b) {
	return fabs(a - b) < eps;
}

bool is_less(dbl a, dbl b) {
	return !is_equal(a, b) && a < b;
}


struct Point {
	int x, y;
	int pos;
	Point() {};
	Point(int x, int y, int pos) : x(x), y(y), pos(pos) {};

};

bool cmp (Point a, Point b) {
	return a.x < b.x || a.x == b.x && a.y < b.y;
}

bool isInside (Point a, Point b, Point c) {
	return (a.x <= b.x && b.x <= c.x && a.y <= b.y && b.y <= c.y);
}

double f (Point a, Point b, Point c) {
	return a.x*(b.y - c.y) + b.x*(c.y - a.y) + c.x*(a.y - b.y);
}

double r (Point p1, Point p2) {
	return sqrt((double)(p1.x - p2.x)*(p1.x - p2.x) + (p1.y - p2.y)*(p1.y - p2.y));
}

void convex_hull_jarvis(vector <Point> & a) {
	if (a.size() == 1) return;
	sort(all(a), cmp);

	vector <Point> hull;
	Point p0 = a[0];
	hull.pb(p0);

	int first = 0, cur = 0;
	do {
		int next = (cur + 1) % (sz(a));
		for (int i = 0; i < sz(a); i++) {
			double sign = f(a[cur], a[next], a[i]);
			if (is_less(sign, 0))
				next = i;
			else if (is_equal(sign, 0)) {
				if (isInside(a[cur], a[next], a[i]))
					next = i;
			}
		}
		cur = next;
		hull.pb(a[next]);
	}
	while (cur != first);
	hull.pop_back();

	vector <Point> hull2;
	for (int i = 0; i < sz(a); i++) {
		for (int j = 0; j < sz(hull); j++) {
			int h1 = j, h2 = (j + 1)%sz(hull);
			if (is_equal(r(hull[h1], a[i]) + r(a[i], hull[h2]), r(hull[h1], hull[h2]))) {
				hull2.pb(a[i]);
				break;
			}
		}
	}
	a = hull2;
	
}

int x[maxn], y[maxn], v[maxn];
vector<Point> points;
vector<Point> points_once;
int bad[maxn];

int main() {
#ifdef _DEBUG
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif
	
	while (true) {
		int n;
		scanf("%d", &n);
		if (n == 0) break;
		int maxv = -INT_MAX;
		for (int i = 0; i < n; i++) {
			scanf("%d%d%d", &x[i], &y[i], &v[i]);
			maxv = max(maxv, v[i]);
			bad[i] = -1;
		}

		if (maxv == 0) {
			for (int i = 0; i < n; i++) {
				printf("0");
			}
			puts("");
			continue;
		}

		points.clear();
		for (int i = 0; i < n; i++)
			if (v[i] == maxv) {
				points.pb(Point(x[i], y[i], i));
			} else {
				bad[i] = 1;
			}
		
		points_once.clear();
		for (int i = 0; i < sz(points); i++) {
			if (bad[points[i].pos] == 1) continue;
			points_once.pb(points[i]);
			for (int j = i + 1; j < sz(points); j++) {
				if (mp(points[i].x, points[i].y) == mp(points[j].x, points[j].y)) {
					bad[points[i].pos] = 1;
					bad[points[j].pos] = 1;
				}
			}
		}

		convex_hull_jarvis(points_once);
		for (int i = 0; i < sz(points_once); i++) {
			if (bad[points_once[i].pos] != 1)
				bad[points_once[i].pos] = 0;
		}

		for (int i = 0; i < n; i++) {
			if (bad[i] == 0) printf("1");
			else printf("0");
		}
		puts("");
	}
	return 0;
}