#include <iostream>
#include <map>
#include <vector>
#include <algorithm>
#include <cstdio>
#include <cmath>
using namespace std;

template <class T> int size(const T&x) { return x.size(); }

typedef long long ll;

typedef pair<int, int> point;
typedef vector<point> polygon;

ll cross(point a, point b) {
    return (ll)a.first * b.second - (ll)a.second * b.first;
}

point sub(point a, point b) {
    return point(a.first - b.first, a.second - b.second);
}

ll ccw(point a, point b, point c) {
    return cross(sub(b,a), sub(c,b));
}

#define MAXN 2000
point hull[MAXN];
bool cmp(const point &a, const point &b) {
    return a < b;
}
int convex_hull(polygon p) {
    int n = size(p), l = 0;
    sort(p.begin(), p.end(), cmp);
    for (int i = 0; i < n; i++) {
        if (i > 0 && p[i] == p[i-1]) continue;
        while (l >= 2 && ccw(hull[l-2], hull[l-1], p[i]) > 0) l--;
        hull[l++] = p[i];
    }
    int r = l;
    for (int i = n - 2; i >= 0; i--) {
        if (p[i] == p[i+1]) continue;
        while (r - l >= 1 && ccw(hull[r-2], hull[r-1], p[i]) > 0) r--;
        hull[r++] = p[i];
    }
    return l == 1 ? 1 : r - 1;
}

int main() {
    int n;
    while (scanf("%d\n", &n) != EOF && n != 0) {
        vector<int> arr(n);
        polygon pts(n);
        map<point, int> cntz;
        int mx = -100;
        for (int i= 0 ; i < n; i++) {
            scanf("%d %d ", &pts[i].first, &pts[i].second);
            scanf("%d\n", &arr[i]);
            mx = max(mx, arr[i]);
        }

        polygon maybe;
        for (int i = 0; i < n; i++) {
            if (mx == arr[i]) {
                maybe.push_back(pts[i]);
                cntz[pts[i]]++;
            }
        }

        int cnt = convex_hull(maybe);
        /*
        printf("%d\n", cnt);
        for (int i = 0; i < cnt; i++) {
            printf("%d %d\n", hull[i].first, hull[i].second);
        }
        */

        for (int i = 0; i < n; i++) {
            if (arr[i] != mx || mx == 0) {
                printf("0");
            } else if (cntz[pts[i]] != 1) {
                printf("0");
            } else {
                bool found = false;
                for (int j = 0; j < cnt; j++) {
                    if (pts[i] == hull[j]) {
                        found = true;
                    }
                }
                if (found) {
                    printf("1");
                } else {
                    printf("0");
                }
            }
        }

        printf("\n");
    }
}
