#include <iostream>
#include <complex>
#include <vector>
#include <algorithm>

using namespace std;
typedef long long int Z;
typedef complex<Z> V;

V pos[512];
Z walk[512];
bool no[512];
bool yes[512];

bool ccw(V a, V b, V c) {
	return ((c - a) * conj(b - a)).imag() > 0;
}

vector<Z> chull(vector<Z>& points) {
	auto cmp = [](Z a, Z b) {
		return make_pair(pos[a].real(), pos[a].imag()) < make_pair(pos[b].real(), pos[b].imag());
	};
	auto eq = [](Z a, Z b) {
		return make_pair(pos[a].real(), pos[a].imag()) == make_pair(pos[b].real(), pos[b].imag());
	};
	sort(points.begin(), points.end(), cmp);
	for(Z i = 1; i < points.size(); ++i) {
		if(eq(points[i - 1], points[i])) {
			no[i - 1] = true;
			no[i] = true;
		}
	}
	points.erase(unique(points.begin(), points.end(), eq), points.end());
	
	int n = points.size();
	if(n <= 2) return points;
	
	vector<Z> hull;
	hull.push_back(points[0]);
	for(int dir = 0; dir != 2; ++dir) {
		if(dir) reverse(points.begin(), points.end());
		
		int start = hull.size();
		for(int i = 0; i < n; ++i) {
			while(hull.size() > start && ccw(pos[hull[hull.size() - 2]], pos[points[i]], pos[hull.back()])) {
				hull.pop_back();
			}
			hull.push_back(points[i]);
		}
	}
	hull.pop_back();
	
	return hull;
}

int main() {
	cin.sync_with_stdio(false);
	
	while(true) {
		Z n;
		cin >> n;
		if(n == 0) break;
		
		fill(no, no + n, false);
		fill(yes, yes + n, false);
		Z fastest = -1;
		for(Z i = 0; i < n; ++i) {
			Z x, y, v;
			cin >> x >> y >> v;
			pos[i] = V(x, y);
			walk[i] = v;
			fastest = max(fastest, v);
		}
		
		if(fastest == 0) {
			for(Z i = 0; i < n; ++i) cout << '0';
			cout << '\n';
		} else {
			vector<Z> points;
			for(int i = 0; i < n; ++i) {
				if(walk[i] == fastest) points.push_back(i);
			}
			
			vector<Z> hull = chull(points);
			for(Z i : hull) yes[i] = true;
			
			for(Z i = 0; i < n; ++i) {
				if(yes[i] && !no[i]) cout << '1';
				else cout << '0';
			}
			cout << '\n';
		}
	}

	return 0;
}
