#include <iostream>
#include <complex>
#include <vector>
#include <algorithm>
#include <set>
#include <iomanip>

using namespace std;
typedef long long int Z;
typedef complex<double> V;
typedef complex<double> Vd;

#define X real()
#define Y imag()

int n;
int ne[50005];
int pr[50005];
int v1[50005];
int v2[50005];

V pos[50005];
Vd posd[50005];
int order[50005];
int orderIdx[50005];

bool ccw(V a, V b, V c) {
	return ((c - a) * conj(b - a)).imag() > 0;
}
bool collinear(V a, V b, V c) {
	return ((c - a) * conj(b - a)).imag() == 0;
}

int quadrant(V v) {
	if(v.X >= 0) {
		if(v.Y >= 0) {
			return 0;
		} else {
			return 3;
		}
	} else {
		if(v.Y >= 0) {
			return 1;
		} else {
			return 2;
		}
	}
}

struct EdgeCmp {
	bool operator()(int a, int b) const {
		if(a == b) return false;
		int a1 = v1[a];
		int a2 = v2[a];
		int b1 = v1[b];
		int b2 = v2[b];
		
		if(a1 == b1) {
			return ccw(pos[a2], pos[a1], pos[b2]);
		}
		if(a2 == b2) {
			return ccw(pos[b1], pos[a2], pos[a1]);
		}
		
		if(ccw(0, pos[a1], pos[b1])) {
			return ccw(pos[a1], pos[b1], pos[a2]);
		} else {
			return ccw(pos[b1], pos[b2], pos[a1]);
		}
	}
};

struct AngleCmp {
	bool operator()(int a, int b) const {
		int qa = quadrant(pos[a]);
		int qb = quadrant(pos[b]);
		if(qa == qb) {
			return ccw(0, pos[a], pos[b]);
		} else {
			return qa < qb;
		}
	}
};

Vd ctrd;
Vd intersection(Vd a, Vd b, Vd c, Vd d) {
	b -= a;
	c -= a;
	d -= a;
	Vd u = c / b;
	Vd v = d / b;
	
	double t = (u.X * v.Y - u.Y * v.X) / (v.Y - u.Y);
	if(!isfinite(t)) t = 0.5;
	if(t < 0) t = 0;
	if(t > 1) t = 1;
	
	return a + t * b;
}

int main() {
	cin.sync_with_stdio(false);
	
	int Te;
	cin >> Te;
	for(int te = 0; te < Te; ++te) {
		double xc, yc;
		cin >> xc >> yc;
//		V ctr(round(xc * 1e4), round(yc * 1e4));
		ctrd = Vd(xc, yc);
//		V ctr = ctrd;
		
		cin >> n;
		for(int i = 0; i < n - 1; ++i) {
			ne[i] = i + 1;
			pr[i + 1] = i;
		}
		ne[n - 1] = 0;
		pr[0] = n - 1;
		
		for(int i = 0; i < n; ++i) {
			double x, y;
			cin >> x >> y;
			posd[i] = V(x, y);
			posd[i] -= ctrd;
			pos[i] = posd[i];
/*			pos[i] = V(round(x * 1e4), round(y * 1e4));
			pos[i] -= ctr;
*/		}
		
		for(int i = 0; i < n; ++i) {
			v1[i] = i;
			v2[i] = ne[i];
			if(!ccw(0, pos[v1[i]], pos[v2[i]])) swap(v1[i], v2[i]);
		}
		
		for(int i = 0; i < n; ++i) {
			order[i] = i;
		}
		sort(order, order + n, AngleCmp());
		
		for(int i = 0; i < n; ++i) {
			orderIdx[order[i]] = i;
		}
		
		set<int, EdgeCmp> edges;
		for(int i = 0; i < n; ++i) {
			if(collinear(0, pos[v1[i]], pos[v2[i]])) {
				while((pos[v1[i]].X + pos[v1[i]].Y > 0) != (pos[v2[i]].X + pos[v2[i]].Y > 0)) { }
				continue;
			}
			if(orderIdx[v1[i]] > orderIdx[v2[i]]) {
				edges.insert(i);
			}
		}
		
		int last = *edges.begin();
		vector<Vd> vis;
		for(int i = 0; i < n; ++i) {
			int v = order[i];
			int asd[2];
			asd[0] = pr[v];
			asd[1] = v;
			
			for(int j = 0; j < 2; ++j) {
				int e = asd[j];
				if(collinear(0, pos[v1[e]], pos[v2[e]])) continue;
				
				if(v == v2[e]) {
					// end
					edges.erase(e);
				}
			}
			for(int j = 0; j < 2; ++j) {
				int e = asd[j];
				if(collinear(0, pos[v1[e]], pos[v2[e]])) continue;
				
				if(v == v1[e]) {
					// start
					edges.insert(e);
				}
			}
			
/*			cout << v << ":\n";
			for(int edge : edges) {
				cout << "  " << edge << "\n";
			}
*/			
			if(!edges.empty()) {
				int bottom = *edges.begin();
				if(bottom != last) {
					vis.push_back(intersection(posd[last], posd[ne[last]], 0, posd[v]));
					vis.push_back(intersection(posd[bottom], posd[ne[bottom]], 0, posd[v]));
				}
				last = bottom;
			}
		}
		vis.push_back(vis.front());
		
		double ret = 0.0;
		for(int i = 1; i < vis.size(); ++i) {
			ret += vis[i].X * vis[i - 1].Y - vis[i - 1].X * vis[i].Y;
		}
/*		for(Vd v : vis) {
			cout << v + ctrd << "\n";
		}
*/		
		cout << setprecision(20) << fixed << 0.5 * abs(ret) << "\n";
	}

	return 0;
}
