#if 1
#include <iostream>
#include <vector>
#include <set>
#include <algorithm>
#include <cstdio>
using namespace std;

struct dot
{
	int x, y, v, id;
	dot() {}
	dot(int x, int y, int v, int id) : x(x), y(y), v(v), id(id) {}
	friend bool operator < (const dot &a, const dot &b)
	{
		return make_pair(a.x, a.y) < make_pair(b.x, b.y);
	}
	friend bool operator == (const dot &a, const dot &b)
	{
		return make_pair(a.x, a.y) == make_pair(b.x, b.y);
	}
};

int area(dot &a, dot &b, dot &c)
{
	return (a.x - c.x) * (b.y - c.y) - (a.y - c.y) * (b.x - c.x);
}

void convex_hull(vector<dot> &dots, vector<dot> &hull)
{
	sort(dots.begin(), dots.end());
	dots.erase(unique(dots.begin(), dots.end()), dots.end());
	if(dots.size() == 3)
	{
		hull = dots;
		return;
	}
	dot s = dots.front(), e = dots.back();
	int sz;
	hull = vector<dot> (1, s);
	for (int i = 1; i < dots.size(); ++i) 
	{
		if( area(e, s, dots[i]) < 0) continue;
		while((sz = hull.size()) >= 2 && area(hull[sz-2], hull[sz-1], dots[i]) < 0)
			hull.pop_back();
		hull.push_back(dots[i]);
	}
	for (int i = dots.size() - 2; i >= 0; --i) 
	{
		if( area(e, s, dots[i]) > 0) continue;
		while((sz = hull.size()) >= 2 && area(hull[sz-2], hull[sz-1], dots[i]) < 0)
			hull.pop_back();
		hull.push_back(dots[i]);
	}
}

int main()
{
#ifdef _DEBUG
	freopen("input.txt", "r", stdin);
#endif
	while(true)
	{
		int n; cin >> n;
		if(n == 0) break;
		vector<int> answer(n);
		set<dot> sdots, ddots;
		vector<dot> origin(n);
		vector<dot> check;
		int maxv = 1;
		for (int i = 0; i < n; ++i)
		{
			cin >> origin[i].x >> origin[i].y >> origin[i].v;
			origin[i].id = i;
			maxv = max(maxv, origin[i].v);
			if(sdots.find(origin[i]) == sdots.end()) sdots.insert(origin[i]);
			else ddots.insert(origin[i]);
		}
		for (int i = 0; i < n; ++i)	if(origin[i].v == maxv) check.push_back(origin[i]);
		vector<dot> hull;
		convex_hull(check, hull);
		for (int i = 0; i < hull.size(); ++i)
			if(ddots.find(hull[i]) == ddots.end())
				answer[hull[i].id] = 1;
		for (int i = 0; i < answer.size(); ++i) cout << answer[i];
		cout << endl;
	}
	return 0;
}
#endif