#if 1
#include <iostream>
#include <vector>
#include <set>
#include <algorithm>
#include <cstdio>
using namespace std;

struct dot
{
	int x, y, v, id;
	dot() {}
	dot(int x, int y, int v, int id) : x(x), y(y), v(v), id(id) {}
	friend bool operator < (const dot &a, const dot &b)
	{
		return make_pair(a.x, a.y) < make_pair(b.x, b.y);
	}
	friend bool operator == (const dot &a, const dot &b)
	{
		return make_pair(a.x, a.y) == make_pair(b.x, b.y);
	}
};

int area(dot &a, dot &b, dot &c)
{
	return (a.x - c.x) * (b.y - c.y) - (a.y - c.y) * (b.x - c.x);
}

void convex_hull(vector<dot> &dots, vector<dot> &hull)
{
	sort(dots.begin(), dots.end());
	dots.erase(unique(dots.begin(), dots.end()), dots.end());
	if(dots.size() <= 3)
	{
		hull = dots;
		return;
	}
	dot s = dots.front(), e = dots.back();
	int sz;
	vector<dot> up(1, s), dn(1, s);
	for (int i = 1; i < dots.size(); ++i) 
	{
		if( area(e, s, dots[i]) <= 0)
		{
			while((sz = up.size()) >= 2 && area(up[sz-2], up[sz-1], dots[i]) > 0)
				up.pop_back();
			up.push_back(dots[i]);
		}
		if( area(e, s, dots[i]) >= 0)
		{
			while((sz = dn.size()) >= 2 && area(dn[sz-2], dn[sz-1], dots[i]) < 0)
				dn.pop_back();
			dn.push_back(dots[i]);
		}
	}
	for (int i = 0; i < up.size(); ++i) hull.push_back(up[i]);
	for (int i = 0; i < dn.size(); ++i) hull.push_back(dn[i]);
}

int main()
{
#ifdef _DEBUG
	freopen("input.txt", "r", stdin);
#endif
	while(true)
	{
		int n; cin >> n;
		if(n == 0) break;
		
		int maxv = 1;
		vector<dot> origin(n);
		for (int i = 0; i < n; ++i)
		{
			cin >> origin[i].x >> origin[i].y >> origin[i].v;
			origin[i].id = i;
			maxv = max(maxv, origin[i].v);

		}

		vector<dot> check;
		set<dot> sdots, ddots;
		for (int i = 0; i < n; ++i)
			if(origin[i].v == maxv)
			{
				check.push_back(origin[i]);
				if(sdots.find(origin[i]) == sdots.end()) sdots.insert(origin[i]);
				else ddots.insert(origin[i]);
			}

		vector<dot> hull;
		convex_hull(check, hull);

		vector<int> answer(n);
		for (int i = 0; i < hull.size(); ++i)
			if(ddots.find(hull[i]) == ddots.end())
				answer[hull[i].id] = 1;
		for (int i = 0; i < answer.size(); ++i) cout << answer[i];
		cout << endl;
	}
	return 0;
}
#endif