#if 1
#include <cmath>
#include <iostream>
#include <vector>
#include <cstdio>
#include <algorithm>
using namespace std;

const double eps = 1e-9;

bool doubleEqual(double a, double b)
{
	return fabs(a - b) < eps;
}
bool doubleLessOrEqual(double a, double b)
{
	return a < b || doubleEqual(a, b);
}
double mySqrt(double v)
{
	if(doubleEqual(v, 0)) return 0;
	return sqrt(v);
}
struct Point 
{
	double x, y;
	int id;
	Point() {}
	Point(double x, double y, int id = 0) : x(x), y(y), id(id) {}
	friend bool operator < (const Point &a, const Point &b)
	{
		return make_pair(a.x, a.y) < make_pair(b.x, b.y);
	}
	void scan()
	{
		scanf("%lf%lf", &x, &y);
	}
	Point operator - (const Point &p) const
	{
		return Point(x - p.x, y - p.y);
	}
	Point operator + (const Point &p) const
	{
		return Point(x + p.x, y + p.y);
	}
	Point operator * (double k) const
	{
		return Point(x * k, y * k);
	}
	double operator * (const Point &p) const
	{
		return y * p.x - x * p.y;
	}
	bool operator == (const Point &p) const
	{
		return doubleEqual(x, p.x) && doubleEqual(y, p.y);
	}
	double distTo(const Point &p) const
	{
		return mySqrt(pow(p.x - x, 2) + pow(p.y - y, 2));
	}
};

double area(Point &a, Point &b, Point &c)
{
	double r = (a.x - c.x) * (b.y - c.y) - (a.y - c.y) * (b.x - c.x);
	if(doubleEqual(r, 0)) return 0;
	return r;
}

bool intersectLines(Point &a, Point &b, Point &c, Point &d, Point &o)
{
	Point v = b - a;
	double s1 = (c - a) * (d - a);
	double s2 = (d - b) * (c - b);
	double s = s1 + s2;

	if(doubleEqual(s, 0)) return false;

	v = v * (s1 / s);
	o = a + v;
	return true;
}

double solve(vector<Point> points, Point L, int n)
{
	Point N = points[0];
	for (int i = 1; i < n; ++i) 
		if(points[i].distTo(L) < N.distTo(L)) 
			N = points[i];
	vector<Point> reorder;
	for (int i = 0; i < n; ++i)
	{
		int ind = (N.id + i) % n;
		reorder.push_back(points[ind]);
	}
	vector<Point> answer (1, N);
	for (int i = 1; i < n; ++i)
	{
		if(area(L, answer.back(), reorder[i]) > 0)
		{
			Point o;
			intersectLines(L, answer.back(), reorder[i-1], reorder[i], o);
			answer.pop_back();
			answer.push_back(o);
			answer.push_back(reorder[i]);
		}
	}
	double ans = 0;
	for (int i = 1; i < answer.size(); ++i)
		ans += area(L, answer[i-1], answer[i]);
	return ans;
}

int main()
{
#ifdef _DEBUG
	freopen("input.txt", "r", stdin);
#endif
	int T; scanf("%d", &T);
	for (int t = 1; t <= T; ++t)
	{
		Point L; scanf("%lf%lf", &L.x, &L.y);
		int n; scanf("%d", &n);
		vector<Point> points(n);
		for (int i = 0; i < n; ++i) scanf("%lf%lf", &points[i].x, &points[i].y);
		double a1, a2;
		
		for (int i = 0; i < n; ++i) points[i].id = i;
		a1 = solve(points, L, n);
		
		reverse(points.begin(), points.end());

		for (int i = 0; i < n; ++i) points[i].id = i;
		a2 = solve(points, L, n);

		printf("%.10lf\n", max(a1, a2) / 2);
	}
	return 0;
}
#endif