#include<cstdlib>

#include<iostream>
#include<fstream>
#include<sstream>

#include<vector>
#include<string>
#include<set>
#include<map>

#include<cmath>
#include<algorithm>
#include<limits>

using namespace std;

#define fi(i, a, b) for (int i = a; i < b; i++)

double sqr(double a)
{
	return a*a;
}

bool doubleEqual(double a, double b)
{
	return fabs(a-b) < 1e-9;
}

bool doubleLessOrEqual(double a,double b)
{
	return a<b || doubleEqual(a,b);
}

bool doubleLess (double a, double b)
{
	return a<b && !doubleEqual(a,b);
}

bool doubleGreaterOrEqual(double a, double b)
{
	return a>b || doubleEqual(a,b);
}

bool doubleGreater (double a, double b)
{
	return a>b && !doubleEqual(a,b);
}

double mySqrt(double a)
{
	if (doubleLess(a,0))
	{
		throw "sqrt(-1)";
	}
	if (a<0) return 0;
	return sqrt(a);
}

struct Point{
public: double x,y; bool inf;
public:
	Point() : x(0), y(0) {inf = false;}
	Point(double x, double y) : x(x), y(y) {inf = false;}
	void scan()
	{
		scanf("%lf %lf", &x, &y);
	}

	void print() const
	{
		printf("%.10lf %.10lf\n", x, y);
	}

	Point operator+(const Point & p) const
	{
		return Point(x+p.x, y+p.y);
	}

	Point operator-(const Point & p) const
	{
		return Point(x-p.x, y-p.y);
	}

	Point operator-() const
	{
		return Point(-x,-y);
	}

	Point operator*(double k) const
	{
		return Point(x*k, y*k);
	}

	Point operator/(double k) const
	{
		return Point(x/k, y/k);
	}

	double operator%(const Point & p) const
	{
		return x*p.x + y*p.y;
	}

	double operator*(const Point & p) const
	{
		return x*p.y - y*p.x;
	}

	double length()
	{
		return sqrt(*this % *this);
	}

};

class Guardian
{
public:
	Guardian(Point pos, int speed) : pos(pos), speed(speed) {}
	
	Point pos;
	int speed;
};

vector<Guardian> guardians;
vector<Point*> vertexSet;
Point *lp;
vector<Point*> hull;

bool comparer(Point* a, Point* b)
{
	double a1 = (a->y - lp->y) / abs(a->x - lp->x);
	double a2 = (b->y - lp->y) / abs(b->x - lp->x);
	if (a1 != a2)
		return a1 > a2;
	else
		return (*a - *lp).length() > (*b - *lp).length();
}

int main()
{
#if defined (DEBUG) || defined (_DEBUG)
	ifstream cin("input.txt");
	ofstream cout("output.txt");
#endif

	int n;
	cin >> n;

	while (n != 0)
	{
		int maxSpeed = 0;
		fi(i, 0, n)
		{
			int x,y,v;
			cin >> x >> y >> v;
			guardians.push_back(Guardian(Point(x, y), v));

			if (maxSpeed < v)
				maxSpeed = v;
		}

		int leftIndex = 0;
		fi(i, 0, guardians.size())
		{
			if (guardians[i].speed == maxSpeed && guardians[i].speed != 0)
			{
				vertexSet.push_back(&guardians[i].pos);
				if (guardians[i].pos.x < vertexSet[leftIndex]->x)
					leftIndex = vertexSet.size() - 1;
			}
		}

		if (vertexSet.size() == 0)
		{
			fi(i, 0, guardians.size())
				cout << '0';
			cout << endl;
			guardians.clear();
			vertexSet.clear();
			hull.clear();
			cin >> n;
			continue;
		}

		lp = vertexSet[leftIndex];
		vertexSet.erase(vertexSet.begin() + leftIndex, vertexSet.begin() + leftIndex  + 1);

		sort(vertexSet.begin(), vertexSet.end(), comparer);

		hull.push_back(lp);

		fi(i, 0, vertexSet.size())
		{
			while (hull.size() != 1 && (*hull[hull.size() - 1] - *hull[hull.size() - 2]) * (*vertexSet[i] - *hull[hull.size() - 1])  > 0  )
			{
				hull.pop_back();
			}
			hull.push_back(vertexSet[i]);
		}

		fi(i, 0, hull.size())
		{
			hull[i]->inf = true;
		}

		fi(i, 0, guardians.size())
		{
			if (guardians[i].pos.inf)
				cout << '1';
			else
				cout << '0';
		}
		cout << endl;


		guardians.clear();
		vertexSet.clear();
		hull.clear();
		cin >> n;
	}


	return 0;
}